# Integrators

## RK45Integrator

::: openscvx.integrators.solve_ivp_rk45
    options:
      show_source: false
      show_root_heading: true

::: openscvx.integrators.rk45_step
    options:
      show_source: false
      show_root_heading: true

## Diffrax Integrators

::: openscvx.integrators.solve_ivp_diffrax
    options:
      show_source: false
      show_root_heading: true

::: openscvx.integrators.solve_ivp_diffrax_prop
    options:
      show_source: false
      show_root_heading: true 